@@ -4,6 +4,7 @@
 #include <QSound>
 #include <QDebug>
 #include <QFile>
+#include <QDesktopServices>
 #include <phonon/MediaObject>
 #include <phonon/MediaSource>
 
@@ -27,7 +28,7 @@ void Audio::createWav(QString filename)
     QString audio = filename;
     audio.chop(3);
     audio.append("wav");
-    audioFile = new QFile(audio);
+    audioFile = new QFile(QDesktopServices::storageLocation(QDesktopServices::DataLocation) + "/AudioWiki/"+ audio);
     if (!audioFile->open(QIODevice::ReadWrite))
         qDebug()<<"cannot write to file";
     else
